@@ -1,5 +1,6 @@
 import os
 import logging
+from types import SimpleNamespace
 from laboro.error import LaboroError
 from laboro.history import History
 from laboro.workspace import Workspace
@@ -11,7 +12,8 @@ from laboro.error.handler import Handler as ErrorHandler
 class Context:
   def __init__(self, logger):
     self.logger = logger
-    self.modules = dict()
+    self.store = SimpleNamespace(memory=dict(),
+                                 files=dict())
     self.history = None
     self.modulemgr = ModuleMgr()
     self.configmgr = ConfigMgr("/etc/laboro/laboro.yml")
