@@ -5,9 +5,9 @@ from laboro.validator import Validator
 
 
 class Module:
-  def __init__(self, filepath, store, args=None):
+  def __init__(self, filepath, context, args=None):
     self.filepath = filepath
-    self.store = store
+    self.context = context
     self.args = args
     self.specification = self._validate_spec()
     self._validate_args()
@@ -18,8 +18,8 @@ class Module:
       if len(args) > 1:
         logging.error("Using method with args instead of kwargs !")
         logging.warning("No argument checking will be done.")
-        self.store[func.__name__] = func(*args[1:])
-        return self.store[func.__name__]
+        self.context.store.memory[func.__name__] = func(*args[1:])
+        return self.context.store.memory[func.__name__]
       else:
         try:
           method = func.__name__
@@ -28,8 +28,8 @@ class Module:
           Validator().validate_method_args(method, kwargs)
         except IndexError as err:
           raise LaboroError(f"UnknownMethodError: Unknown method: {method}") from err
-        self.store[func.__name__] = func(self, **kwargs)
-        return self.store[func.__name__]
+        self.context.store.memory[func.__name__] = func(self, **kwargs)
+        return self.context.store.memory[func.__name__]
     return wrapper
 
   def _validate_spec(self):
