@@ -53,7 +53,7 @@ class Workflow:
   def _instantiate(self, module, cls, args):
     logging.info(f"[+] Object instantiation: {module}.{cls}")
     mod = self.context.modulemgr.get_class_from_module(cls=cls, module=module)
-    return mod(store=self.store, args=args)
+    return mod(context=self.context, args=args)
 
   def run(self):
     """Run the workflow."""
